==> measures-0.0.2.tar.gz: lib/src/azimuth.dart <==
import 'constants.dart';

/// An [Azimuth] intended to deal with measurements of azimuthal angles
/// such as direction/bearing/heading, etc.
///
/// In navigation, bearings or azimuth are measured relative to north.
/// By convention, viewed from above, bearing angles are positive clockwise,
/// so a bearing of 45° corresponds to a north-east orientation.
/// Negative bearings are not used in navigation, so a north-west orientation
/// corresponds to a bearing of 315°.
///
/// When created the [Azimuth] value is normalized between 0.0 and 360.0 degrees.
class Azimuth {
  final double _degrees;

  /// Creates an [Azimuth] instance from [int] or [double] value of degrees.
  const Azimuth.fromDeg(num degrees) : _degrees = (degrees + 360.0) % 360.0;

  /// Creates an [Azimuth] instance from [int] or [double] value of radians.
  factory Azimuth.fromRad(num radians) => Azimuth.fromDeg(radians * radToDeg);

  /// Creates an [Azimuth] instance with NaN value.
  const Azimuth.nan() : _degrees = double.nan;

  /// Creates an [Azimuth] instance with infinity value.
  const Azimuth.infinity() : _degrees = double.infinity;

  /// Creates an [Azimuth] instance with 0.0 value.
  const Azimuth.zero() : _degrees = 0.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.quadrant() : _degrees = 90.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.sextant() : _degrees = 60.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.octant() : _degrees = 45.0;

  /// Returns a [int] hash code for a numerical value of [Azimuth] instance.
  @override
  int get hashCode => _degrees.hashCode;

  /// Returns [Azimuth]'s value in degrees
  double get deg => _degrees;

  /// Returns [Azimuth]'s value in radians
  double get rad => _degrees * degToRad;

  /// Whether the [Azimuth] has the 0.0 value.
  bool get isZero => _degrees == 0.0;

  /// Whether the [Azimuth] has the Not-a-Number value.
  bool get isNaN => _degrees.isNaN;

  /// Whether the [Azimuth] has positive infinity value.
  bool get isInfinite => _degrees.isInfinite;

  /// String representation of the value of [Azimuth]
  String get toStringDeg => '${_degrees.toStringAsFixed(1)}°';

  /// String representation of the instance of [Azimuth]
  String toString() => 'Azimuth: ${_degrees.toStringAsFixed(1)}°';

  @override
  bool operator ==(Object other) =>
      other is Azimuth && _degrees == other._degrees;
  bool operator >(Azimuth other) => _degrees > other._degrees;
  bool operator >=(Azimuth other) => _degrees >= other._degrees;
  bool operator <(Azimuth other) => _degrees < other._degrees;
  bool operator <=(Azimuth other) => _degrees <= other._degrees;
  Azimuth operator +(Azimuth other) =>
      Azimuth.fromDeg(_degrees + other._degrees);
  Azimuth operator -(Azimuth other) =>
      Azimuth.fromDeg(_degrees - other._degrees);
  Azimuth operator *(num other) => Azimuth.fromDeg(_degrees * other);
  Azimuth operator /(num other) => Azimuth.fromDeg(_degrees / other);
}

==> measures-0.2.2.tar.gz: lib/src/azimuth.dart <==
import 'constants.dart';

/// An [Azimuth] intended to deal with measurements of azimuthal angles
/// such as direction/bearing/heading, etc.
///
/// In navigation, bearings or azimuth are measured relative to north.
/// By convention, viewed from above, bearing angles are positive clockwise,
/// so a bearing of 45° corresponds to a north-east orientation.
/// Negative bearings are not used in navigation, so a north-west orientation
/// corresponds to a bearing of 315°.
///
/// When created the [Azimuth] value is normalized between 0.0 and 360.0 degrees.
class Azimuth {
  final double _degrees;

  /// Creates an [Azimuth] instance from [int] or [double] value of degrees.
  const Azimuth.fromDeg(num degrees) : _degrees = (degrees + 360.0) % 360.0;

  /// Creates an [Azimuth] instance from [int] or [double] value of radians.
  factory Azimuth.fromRad(num radians) => Azimuth.fromDeg(radians * radToDeg);

  /// Creates an [Azimuth] instance with NaN value.
  const Azimuth.nan() : _degrees = double.nan;

  /// Creates an [Azimuth] instance with infinity value.
  const Azimuth.infinity() : _degrees = double.infinity;

  /// Creates an [Azimuth] instance with 0.0 value.
  const Azimuth.zero() : _degrees = 0.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.quadrant() : _degrees = 90.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.sextant() : _degrees = 60.0;

  /// Creates an [Azimuth] instance with 90.0 value.
  const Azimuth.octant() : _degrees = 45.0;

  /// Returns an [int] hash code for a numerical value of [Azimuth] instance.
  @override
  int get hashCode => _degrees.hashCode;

  /// Returns [Azimuth]'s value in degrees
  double get deg => _degrees;

  /// Returns [Azimuth]'s value in radians
  double get rad => _degrees * degToRad;

  /// Whether the [Azimuth] has the 0.0 value.
  bool get isZero => _degrees == 0.0;

  /// Whether the [Azimuth] has the Not-a-Number value.
  bool get isNaN => _degrees.isNaN;

  /// Whether the [Azimuth] has positive infinity value.
  bool get isInfinite => _degrees.isInfinite;

  /// String representation of the value of [Azimuth]
  String get toStringDeg => '${_degrees.toStringAsFixed(1)}°';

  /// String representation of the instance of [Azimuth]
  String toString() => 'Azimuth: ${_degrees.toStringAsFixed(1)}°';

  @override
  bool operator ==(Object other) =>
      other is Azimuth && _degrees == other._degrees;
  bool operator >(Azimuth other) => _degrees > other._degrees;
  bool operator >=(Azimuth other) => _degrees >= other._degrees;
  bool operator <(Azimuth other) => _degrees < other._degrees;
  bool operator <=(Azimuth other) => _degrees <= other._degrees;
  Azimuth operator +(Azimuth other) =>
      Azimuth.fromDeg(_degrees + other._degrees);
  Azimuth operator -(Azimuth other) =>
      Azimuth.fromDeg(_degrees - other._degrees);
  Azimuth operator *(num other) => Azimuth.fromDeg(_degrees * other);
  Azimuth operator /(num other) => Azimuth.fromDeg(_degrees / other);
}
